@@ -53,7 +53,49 @@ pub fn add_module_constants(m: &PyModule) -> PyResult<()> {
     add_constant!(EFFECT_FADEOUT)?;
 
     // Key
-    add_constant!(KEY_NONE)?;
+    add_constant!(KEY_BACKSPACE)?;
+    add_constant!(KEY_TAB)?;
+    add_constant!(KEY_RETURN)?;
+    add_constant!(KEY_ESCAPE)?;
+    add_constant!(KEY_SPACE)?;
+    add_constant!(KEY_EXCLAIM)?;
+    add_constant!(KEY_QUOTEDBL)?;
+    add_constant!(KEY_HASH)?;
+    add_constant!(KEY_DOLLAR)?;
+    add_constant!(KEY_PERCENT)?;
+    add_constant!(KEY_AMPERSAND)?;
+    add_constant!(KEY_QUOTE)?;
+    add_constant!(KEY_LEFTPAREN)?;
+    add_constant!(KEY_RIGHTPAREN)?;
+    add_constant!(KEY_ASTERISK)?;
+    add_constant!(KEY_PLUS)?;
+    add_constant!(KEY_COMMA)?;
+    add_constant!(KEY_MINUS)?;
+    add_constant!(KEY_PERIOD)?;
+    add_constant!(KEY_SLASH)?;
+    add_constant!(KEY_0)?;
+    add_constant!(KEY_1)?;
+    add_constant!(KEY_2)?;
+    add_constant!(KEY_3)?;
+    add_constant!(KEY_4)?;
+    add_constant!(KEY_5)?;
+    add_constant!(KEY_6)?;
+    add_constant!(KEY_7)?;
+    add_constant!(KEY_8)?;
+    add_constant!(KEY_9)?;
+    add_constant!(KEY_COLON)?;
+    add_constant!(KEY_SEMICOLON)?;
+    add_constant!(KEY_LESS)?;
+    add_constant!(KEY_EQUALS)?;
+    add_constant!(KEY_GREATER)?;
+    add_constant!(KEY_QUESTION)?;
+    add_constant!(KEY_AT)?;
+    add_constant!(KEY_LEFTBRACKET)?;
+    add_constant!(KEY_BACKSLASH)?;
+    add_constant!(KEY_RIGHTBRACKET)?;
+    add_constant!(KEY_CARET)?;
+    add_constant!(KEY_UNDERSCORE)?;
+    add_constant!(KEY_BACKQUOTE)?;
     add_constant!(KEY_A)?;
     add_constant!(KEY_B)?;
     add_constant!(KEY_C)?;
@@ -80,33 +122,7 @@ pub fn add_module_constants(m: &PyModule) -> PyResult<()> {
     add_constant!(KEY_X)?;
     add_constant!(KEY_Y)?;
     add_constant!(KEY_Z)?;
-    add_constant!(KEY_1)?;
-    add_constant!(KEY_2)?;
-    add_constant!(KEY_3)?;
-    add_constant!(KEY_4)?;
-    add_constant!(KEY_5)?;
-    add_constant!(KEY_6)?;
-    add_constant!(KEY_7)?;
-    add_constant!(KEY_8)?;
-    add_constant!(KEY_9)?;
-    add_constant!(KEY_0)?;
-    add_constant!(KEY_RETURN)?;
-    add_constant!(KEY_ESCAPE)?;
-    add_constant!(KEY_BACKSPACE)?;
-    add_constant!(KEY_TAB)?;
-    add_constant!(KEY_SPACE)?;
-    add_constant!(KEY_MINUS)?;
-    add_constant!(KEY_EQUALS)?;
-    add_constant!(KEY_LEFTBRACKET)?;
-    add_constant!(KEY_RIGHTBRACKET)?;
-    add_constant!(KEY_BACKSLASH)?;
-    add_constant!(KEY_NONUSHASH)?;
-    add_constant!(KEY_SEMICOLON)?;
-    add_constant!(KEY_APOSTROPHE)?;
-    add_constant!(KEY_GRAVE)?;
-    add_constant!(KEY_COMMA)?;
-    add_constant!(KEY_PERIOD)?;
-    add_constant!(KEY_SLASH)?;
+    add_constant!(KEY_DELETE)?;
     add_constant!(KEY_CAPSLOCK)?;
     add_constant!(KEY_F1)?;
     add_constant!(KEY_F2)?;
@@ -126,7 +142,6 @@ pub fn add_module_constants(m: &PyModule) -> PyResult<()> {
     add_constant!(KEY_INSERT)?;
     add_constant!(KEY_HOME)?;
     add_constant!(KEY_PAGEUP)?;
-    add_constant!(KEY_DELETE)?;
     add_constant!(KEY_END)?;
     add_constant!(KEY_PAGEDOWN)?;
     add_constant!(KEY_RIGHT)?;
@@ -150,7 +165,6 @@ pub fn add_module_constants(m: &PyModule) -> PyResult<()> {
     add_constant!(KEY_KP_9)?;
     add_constant!(KEY_KP_0)?;
     add_constant!(KEY_KP_PERIOD)?;
-    add_constant!(KEY_NONUSBACKSLASH)?;
     add_constant!(KEY_APPLICATION)?;
     add_constant!(KEY_POWER)?;
     add_constant!(KEY_KP_EQUALS)?;
@@ -182,24 +196,6 @@ pub fn add_module_constants(m: &PyModule) -> PyResult<()> {
     add_constant!(KEY_VOLUMEDOWN)?;
     add_constant!(KEY_KP_COMMA)?;
     add_constant!(KEY_KP_EQUALSAS400)?;
-    add_constant!(KEY_INTERNATIONAL1)?;
-    add_constant!(KEY_INTERNATIONAL2)?;
-    add_constant!(KEY_INTERNATIONAL3)?;
-    add_constant!(KEY_INTERNATIONAL4)?;
-    add_constant!(KEY_INTERNATIONAL5)?;
-    add_constant!(KEY_INTERNATIONAL6)?;
-    add_constant!(KEY_INTERNATIONAL7)?;
-    add_constant!(KEY_INTERNATIONAL8)?;
-    add_constant!(KEY_INTERNATIONAL9)?;
-    add_constant!(KEY_LANG1)?;
-    add_constant!(KEY_LANG2)?;
-    add_constant!(KEY_LANG3)?;
-    add_constant!(KEY_LANG4)?;
-    add_constant!(KEY_LANG5)?;
-    add_constant!(KEY_LANG6)?;
-    add_constant!(KEY_LANG7)?;
-    add_constant!(KEY_LANG8)?;
-    add_constant!(KEY_LANG9)?;
     add_constant!(KEY_ALTERASE)?;
     add_constant!(KEY_SYSREQ)?;
     add_constant!(KEY_CANCEL)?;
@@ -292,10 +288,7 @@ pub fn add_module_constants(m: &PyModule) -> PyResult<()> {
     add_constant!(KEY_KBDILLUMUP)?;
     add_constant!(KEY_EJECT)?;
     add_constant!(KEY_SLEEP)?;
-    add_constant!(KEY_APP1)?;
-    add_constant!(KEY_APP2)?;
-    add_constant!(KEY_AUDIOREWIND)?;
-    add_constant!(KEY_AUDIOFASTFORWARD)?;
+    add_constant!(KEY_NONE)?;
     add_constant!(KEY_SHIFT)?;
     add_constant!(KEY_CTRL)?;
     add_constant!(KEY_ALT)?;
